Class: Google::Cloud::Workflows::Executions::V1::Execution::StackTraceElement::Position

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workflows/executions/v1/executions.rb

Overview

Position contains source position information about the stack trace element such as line number, column number and length of the code block in bytes.

Instance Attribute Summary collapse

Instance Attribute Details

#column::Integer



116
117
118
119
# File 'proto_docs/google/cloud/workflows/executions/v1/executions.rb', line 116

class Position
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#length::Integer



116
117
118
119
# File 'proto_docs/google/cloud/workflows/executions/v1/executions.rb', line 116

class Position
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#line::Integer



116
117
118
119
# File 'proto_docs/google/cloud/workflows/executions/v1/executions.rb', line 116

class Position
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end